@@ -1,25 +1,13 @@
-/***************************************************************************
-
-    Copyright 2007-2008 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
-
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007-2008 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "containermodel.h"
 
 #include "containermimedata.h"
 #include "vocabularymimedata.h"
 
-#include <KEduVocDocument>
-#include <KEduVocLesson>
 #include <KEduVocWordtype>
 #include <KEduVocExpression>
 
