@@ -1,18 +1,10 @@
-/***************************************************************************
-    Copyright 1999-2001 Ewald Arnold <kvoctrain@ewald-arnold.de>
-    Copyright 2004-2007 Peter Hedlund <peter.hedlund@kdemail.net>
-    Copyright 2007-2009 Frederik Gladhorn <gladhorn@kde.org>
-    Copyright 2008 Daniel Laidig <d.laidig@gmx.de>
-***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 1999-2001 Ewald Arnold <kvoctrain@ewald-arnold.de>
+    SPDX-FileCopyrightText: 2004-2007 Peter Hedlund <peter.hedlund@kdemail.net>
+    SPDX-FileCopyrightText: 2007-2009 Frederik Gladhorn <gladhorn@kde.org>
+    SPDX-FileCopyrightText: 2008 Daniel Laidig <d.laidig@gmx.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "editor.h"
 
@@ -407,7 +399,6 @@ void EditorWindow::initActions()
     ParleyActions::create(ParleyActions::SearchVocabulary, this, SLOT(startSearch()), actionCollection());
     ParleyActions::create(ParleyActions::ShowScriptManager, this, SLOT(slotShowScriptManager()), actionCollection());
     ParleyActions::create(ParleyActions::LanguagesProperties, m_mainWindow->parleyDocument(), SLOT(languageProperties()), actionCollection());
-    ParleyActions::createUploadAction(m_mainWindow->parleyDocument(), SLOT(uploadFile()), actionCollection());
 
     new EditorWindowAdaptor(this);
 
