@@ -1,16 +1,7 @@
-/***************************************************************************
-Copyright 2009 Frederik Gladhorn <gladhorn@kde.org>
-***************************************************************************/
-
-/***************************************************************************
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-***************************************************************************/
-
+/*
+    SPDX-FileCopyrightText: 2009 Frederik Gladhorn <gladhorn@kde.org>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "parleyactions.h"
 
 #include "prefs.h"
@@ -212,12 +203,3 @@ QAction* ParleyActions::createDownloadAction(const QObject* recvr, const char* s
     pAction->setToolTip(i18n("Downloads new vocabulary collections"));
     return pAction;
 }
-
-QAction* ParleyActions::createUploadAction(const QObject* recvr, const char* slot, KActionCollection* collection)
-{
-    QAction *pAction = new QAction(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")), i18n("&Upload Vocabulary Document..."), collection);
-    collection->addAction(QStringLiteral("file_upload"), pAction);
-    QObject::connect(pAction, SIGNAL(triggered(bool)), recvr, slot);
-    pAction->setToolTip(i18n("Share the current vocabulary collection with other users"));
-    return pAction;
-}
